@@ -3,6 +3,10 @@
 plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 	method = "abs", axLabs = NULL, axLab.pos = NULL,
 	LA = FALSE, ...) {
+
+	if (!requireNamespace("rgl", quietly = TRUE)) {
+		stop("You need to install package rgl to use this function")
+		}
 	
 	# Function to plot 3D hive plots
 	# inspired by the work of Martin Kryzwinski
@@ -29,7 +33,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 	HPD$nodes$radius <- nodes$radius # important, as HPD is passed
 	# to drawHiveSpline so it must be updated here
 
-	bg3d("black") # black background to rgl graphics
+	rgl::bg3d("black") # black background to rgl graphics
 
 ##### Four dimensional case (nx = 4, 5, 6 with rgl graphics)
 
@@ -37,10 +41,16 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 	
 	if (nx == 4) {
 		
-		n1 <- subset(nodes, axis == 1)
-		n2 <- subset(nodes, axis == 2)
-		n3 <- subset(nodes, axis == 3)
-		n4 <- subset(nodes, axis == 4)
+		# n1 <- subset(nodes, axis == 1)
+		# n2 <- subset(nodes, axis == 2)
+		# n3 <- subset(nodes, axis == 3)
+		# n4 <- subset(nodes, axis == 4)
+
+		n1 <- nodes[nodes[,"axis"] == 1,]
+		n2 <- nodes[nodes[,"axis"] == 2,]
+		n3 <- nodes[nodes[,"axis"] == 3,]
+		n4 <- nodes[nodes[,"axis"] == 4,]
+
 		max1 <- max(n1$radius)
 		max2 <- max(n2$radius)
 		max3 <- max(n3$radius)
@@ -55,10 +65,10 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 		phi <- c(54.7, 54.7, 125.3, 125.3, 125.3, 125.3, 54.7, 54.7)
 		ax.df <- data.frame(radius = r, theta = theta, phi = phi)
 		ax.coord <- sph2cart(ax.df)
-		segments3d(ax.coord[1:2,], col = axis.cols[1], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[3:4,], col = axis.cols[2], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[5:6,], col = axis.cols[3], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[7:8,], col = axis.cols[4], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[1:2,], col = axis.cols[1], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[3:4,], col = axis.cols[2], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[5:6,], col = axis.cols[3], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[7:8,], col = axis.cols[4], line_antialias = TRUE, lwd = 4)
 
 	# now add nodes
 
@@ -74,7 +84,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 			rep(-135, length(n4$radius)))
 		n.df <- data.frame(radius = r, theta = theta, phi = phi)
 		n.coord <- sph2cart(n.df)
-		spheres3d(n.coord$x, n.coord$y, n.coord$z, col = c(n1$color, n2$color, n3$color, n4$color),
+		rgl::spheres3d(n.coord$x, n.coord$y, n.coord$z, col = c(n1$color, n2$color, n3$color, n4$color),
 		radius = c(n1$size, n2$size, n3$size, n4$size))
 		}
 		
@@ -84,7 +94,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 	
 	# add a center sphere
 	
-		spheres3d(0, 0, 0, col = "gray", radius = ch)
+		rgl::spheres3d(0, 0, 0, col = "gray", radius = ch)
 
 	# add axis labels if requested
 	
@@ -97,7 +107,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 		theta <- c(45, -45, 135, -135)
 		t.df <- data.frame(radius = r, theta = theta, phi = phi)
 		t.coord <- sph2cart(t.df)
-		text3d(t.coord, texts = axLabs, adj = c(0.5, 0.5), col = "white")
+		rgl::text3d(t.coord, texts = axLabs, adj = c(0.5, 0.5), col = "white")
 		}
 		
 		} # end of 4D
@@ -108,11 +118,18 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 	
 	if (nx == 5) {
 		
-		n1 <- subset(nodes, axis == 1)
-		n2 <- subset(nodes, axis == 2)
-		n3 <- subset(nodes, axis == 3)
-		n4 <- subset(nodes, axis == 4)
-		n5 <- subset(nodes, axis == 5)
+		# n1 <- subset(nodes, axis == 1)
+		# n2 <- subset(nodes, axis == 2)
+		# n3 <- subset(nodes, axis == 3)
+		# n4 <- subset(nodes, axis == 4)
+		# n5 <- subset(nodes, axis == 5)
+
+		n1 <- nodes[nodes[,"axis"] == 1,]
+		n2 <- nodes[nodes[,"axis"] == 2,]
+		n3 <- nodes[nodes[,"axis"] == 3,]
+		n4 <- nodes[nodes[,"axis"] == 4,]
+		n5 <- nodes[nodes[,"axis"] == 5,]
+
 		max1 <- max(n1$radius)
 		max2 <- max(n2$radius)
 		max3 <- max(n3$radius)
@@ -130,11 +147,11 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 		phi <- c(90, 90, 90, 90, 90, 90, 0, 0, 180, 180)
 		ax.df <- data.frame(radius = r, theta = theta, phi = phi)
 		ax.coord <- sph2cart(ax.df)
-		segments3d(ax.coord[1:2,], col = axis.cols[1], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[3:4,], col = axis.cols[2], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[5:6,], col = axis.cols[3], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[7:8,], col = axis.cols[4], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[9:10,], col = axis.cols[5], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[1:2,], col = axis.cols[1], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[3:4,], col = axis.cols[2], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[5:6,], col = axis.cols[3], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[7:8,], col = axis.cols[4], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[9:10,], col = axis.cols[5], line_antialias = TRUE, lwd = 4)
 	
 	# now add nodes
 		
@@ -152,7 +169,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 			rep(0, length(n5$radius)))
 		n.df <- data.frame(radius = r, theta = theta, phi = phi)
 		n.coord <- sph2cart(n.df)
-		spheres3d(n.coord$x, n.coord$y, n.coord$z, col = c(n1$color, n2$color, n3$color, n4$color, n5$color),
+		rgl::spheres3d(n.coord$x, n.coord$y, n.coord$z, col = c(n1$color, n2$color, n3$color, n4$color, n5$color),
 		radius = c(n1$size, n2$size, n3$size, n4$size, n5$size))
 		}
 		
@@ -162,7 +179,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 
 	# add a center sphere
 	
-		spheres3d(0, 0, 0, col = "gray", radius = ch)
+		rgl::spheres3d(0, 0, 0, col = "gray", radius = ch)
 
 	# add axis labels if requested
 	
@@ -175,7 +192,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 		theta <- c(0, 120, 240, 0, 0)
 		t.df <- data.frame(radius = r, theta = theta, phi = phi)
 		t.coord <- sph2cart(t.df)
-		text3d(t.coord, texts = axLabs, adj = c(0.5, 0.5), col = "white")
+		rgl::text3d(t.coord, texts = axLabs, adj = c(0.5, 0.5), col = "white")
 		}
 
 		} # end of 5D
@@ -186,12 +203,20 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 	
 	if (nx == 6) {
 		
-		n1 <- subset(nodes, axis == 1)
-		n2 <- subset(nodes, axis == 2)
-		n3 <- subset(nodes, axis == 3)
-		n4 <- subset(nodes, axis == 4)
-		n5 <- subset(nodes, axis == 5)
-		n6 <- subset(nodes, axis == 6)
+		# n1 <- subset(nodes, axis == 1)
+		# n2 <- subset(nodes, axis == 2)
+		# n3 <- subset(nodes, axis == 3)
+		# n4 <- subset(nodes, axis == 4)
+		# n5 <- subset(nodes, axis == 5)
+		# n6 <- subset(nodes, axis == 6)
+
+		n1 <- nodes[nodes[,"axis"] == 1,]
+		n2 <- nodes[nodes[,"axis"] == 2,]
+		n3 <- nodes[nodes[,"axis"] == 3,]
+		n4 <- nodes[nodes[,"axis"] == 4,]
+		n5 <- nodes[nodes[,"axis"] == 5,]
+		n6 <- nodes[nodes[,"axis"] == 6,]
+
 		max1 <- max(n1$radius)
 		max2 <- max(n2$radius)
 		max3 <- max(n3$radius)
@@ -211,12 +236,12 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 		phi <- c(90, 90, 90, 90, 90, 90, 90, 90, 0, 0, 180, 180)
 		ax.df <- data.frame(radius = r, theta = theta, phi = phi)
 		ax.coord <- sph2cart(ax.df)
-		segments3d(ax.coord[1:2,], col = axis.cols[1], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[3:4,], col = axis.cols[2], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[5:6,], col = axis.cols[3], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[7:8,], col = axis.cols[4], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[9:10,], col = axis.cols[5], line_antialias = TRUE, lwd = 4)
-		segments3d(ax.coord[11:12,], col = axis.cols[6], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[1:2,], col = axis.cols[1], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[3:4,], col = axis.cols[2], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[5:6,], col = axis.cols[3], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[7:8,], col = axis.cols[4], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[9:10,], col = axis.cols[5], line_antialias = TRUE, lwd = 4)
+		rgl::segments3d(ax.coord[11:12,], col = axis.cols[6], line_antialias = TRUE, lwd = 4)
 	
 		# now add nodes
 		
@@ -236,7 +261,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 			rep(0, length(n6$radius)))
 		n.df <- data.frame(radius = r, theta = theta, phi = phi)
 		n.coord <- sph2cart(n.df)
-		spheres3d(n.coord$x, n.coord$y, n.coord$z, col = c(n1$color, n2$color, n3$color, n4$color, n5$color, n6$color),
+		rgl::spheres3d(n.coord$x, n.coord$y, n.coord$z, col = c(n1$color, n2$color, n3$color, n4$color, n5$color, n6$color),
 		radius = c(n1$size, n2$size, n3$size, n4$size, n5$size, n6$size))
 		}
 		
@@ -246,7 +271,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 
 	# add a center sphere
 	
-		spheres3d(0, 0, 0, col = "gray", radius = ch)
+		rgl::spheres3d(0, 0, 0, col = "gray", radius = ch)
 
 	# add axis labels if requested
 	
@@ -259,7 +284,7 @@ plot3dHive <- function(HPD, ch = 1, dr.nodes = TRUE,
 		theta <- c(0, 90, 180, 270, 0, 0)
 		t.df <- data.frame(radius = r, theta = theta, phi = phi)
 		t.coord <- sph2cart(t.df)
-		text3d(t.coord, texts = axLabs, adj = c(0.5, 0.5), col = "white")
+		rgl::text3d(t.coord, texts = axLabs, adj = c(0.5, 0.5), col = "white")
 		}
 		
 		} # end of 6D
